@@ -12,6 +12,7 @@ import pandas as pd
 import json
 import numpy as np
 import warnings
+
 from ml_wrappers.model.predictions_wrapper import (
     PredictionsModelWrapperClassification,
     PredictionsModelWrapperRegression,
@@ -24,15 +25,30 @@ from responsibleai.serialization_utilities import serialize_json_safe
 from pathlib import Path
 from azureml.core import ScriptRunConfig
 
+from ._loggerfactory import _LoggerFactory, track
 
+_ai_logger = None
 submit_locally_managed_run = False
 
 
+def _get_logger():
+    global _ai_logger
+    if _ai_logger is None:
+        _ai_logger = _LoggerFactory.get_logger(__file__)
+    return _ai_logger
+
+
+_get_logger()
+
+
+@track(_get_logger)
 def _compute_and_upload_rai_insights_internal(
     current_run: Run, automl_child_run: Run
 ):
     automl_child_run.download_files("outputs/rai")
 
+    _ai_logger.info("Generating RAI insights for AutoML child run")
+
     metadata = None
     with open("outputs/rai/metadata.json", "r") as fp:
         metadata = json.load(fp)
@@ -98,6 +114,8 @@ def _compute_and_upload_rai_insights_internal(
     train = train.drop(columns=dropped_features)
     test = test.drop(columns=dropped_features)
     if len(text_features) == 0 and len(datetime_features) == 0:
+        _ai_logger.info("Generating RAI insights for {} samples.".format(
+            len(test)))
         rai_insights = RAIInsights(
             model=model_wrapper,
             train=train,
@@ -121,14 +139,16 @@ def _compute_and_upload_rai_insights_internal(
             json.dump(rai_dict, json_file)
         current_run.upload_folder("ux_json", "ux_json")
         automl_child_run.tag("model_rai", "True")
+        _ai_logger.info("Successfully generated and uploaded the RAI insights")
     else:
-        warnings.warn(
-            "Currently RAI is not supported for " "text and datetime features"
-        )
-
+        warnings.warn("Currently RAI is not supported for "
+                      "text and datetime features")
+        _ai_logger.info("Currently RAI is not supported for "
+                        "text and datetime features")
     current_run.complete()
 
 
+@track(_get_logger)
 def _create_project_folder(
     automl_parent_run_id: str, automl_child_run_id: str
 ):
@@ -162,6 +182,7 @@ def _create_project_folder(
     return project_folder
 
 
+@track(_get_logger)
 def _create_run_configuration(automl_child_run_id, ws):
     automl_run = ws.get_run(automl_child_run_id)
     run_configuration = RunConfiguration()
@@ -187,6 +208,7 @@ def call_with_output(command):
     return (success, output)
 
 
+@track(_get_logger)
 def execute_automl_inference_script(automl_child_run_id, ws):
     automl_run = ws.get_run(automl_child_run_id)
 
@@ -211,6 +233,7 @@ def execute_automl_inference_script(automl_child_run_id, ws):
     print(success)
 
     if not success:
+        _ai_logger.info("Error creating conda environment")
         raise Exception(output)
 
     inference_script_name = (
@@ -229,6 +252,7 @@ def execute_automl_inference_script(automl_child_run_id, ws):
     print(success)
 
     if not success:
+        _ai_logger.info("Error running automl script in conda environment")
         raise Exception(output)
 
     command = [
@@ -244,9 +268,10 @@ def execute_automl_inference_script(automl_child_run_id, ws):
     print(success)
 
 
+@track(_get_logger)
 def compute_and_upload_rai_insights(
     automl_parent_run_id: Optional[str] = None,
-    automl_child_run_id: Optional[str] = None,
+    automl_child_run_id: Optional[str] = None
 ):
     print("The automl child run-id is: " + str(automl_child_run_id))
     print("The automl parent run-id is: " + str(automl_parent_run_id))
@@ -255,6 +280,8 @@ def compute_and_upload_rai_insights(
     print("The current run-id is: " + rai_run.id)
 
     if submit_locally_managed_run:
+        _ai_logger.info("Submitting locally managed run to compute AutoML "
+                        "artifacts.")
         project_folder = _create_project_folder(
             automl_parent_run_id, automl_child_run_id
         )
@@ -268,6 +295,8 @@ def compute_and_upload_rai_insights(
         automl_inference_run = rai_run.experiment.submit(config=src)
         automl_inference_run.wait_for_completion()
     else:
+        _ai_logger.info("Creating local conda environment to compute "
+                        "AutoML artifacts.")
         # Create conda env from native commands and submit script
         project_folder = _create_project_folder(
             automl_parent_run_id, automl_child_run_id
